var searchData=
[
  ['r_0',['r',['../struct___d3_d_c_o_l_o_r_v_a_l_u_e.html#a75fb19f8ec022e84b099bdc5752487bb',1,'_D3DCOLORVALUE::r()'],['../class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2',1,'Ogre::ColourValue::r()']]],
  ['r_5fmask_1',['R_MASK',['../class_ogre_1_1_hlms_unlit_datablock.html#a2bbe39df235736f6844ce5cc9b7a0897',1,'Ogre::HlmsUnlitDatablock']]],
  ['range_2',['range',['../struct_ogre_1_1_metal_tex_region.html#a31ef1ac128e74df2d3ed27c3d93b42d4',1,'Ogre::MetalTexRegion::range()'],['../struct_ogre_1_1_metal_buffer_region.html#a9f3f0ff1faa7aedf3533be9838d5fa0d',1,'Ogre::MetalBufferRegion::range()']]],
  ['raymarchstepscale_3',['rayMarchStepScale',['../struct_ogre_1_1_vct_cascade_setting.html#a009c771d10905904c7ebaa507d6c5d4b',1,'Ogre::VctCascadeSetting']]],
  ['rbits_4',['rbits',['../struct_ogre_1_1_pixel_format_description.html#a5c56c4c4b002b5c389ebbcc29d2d2d35',1,'Ogre::PixelFormatDescription']]],
  ['readmask_5',['readMask',['../struct_ogre_1_1_stencil_params.html#a2e887fc56a085cfe5ec7ce4ba649bda9',1,'Ogre::StencilParams']]],
  ['readonly_6',['readOnly',['../struct_ogre_1_1_render_pass_depth_target.html#ae14488d43193f02cd4511231cf686940',1,'Ogre::RenderPassDepthTarget::readOnly()'],['../struct_ogre_1_1_render_pass_stencil_target.html#a0a2110a4d87d8fae1313568aa6349810',1,'Ogre::RenderPassStencilTarget::readOnly()']]],
  ['readonlybuffers_7',['readOnlyBuffers',['../struct_ogre_1_1_vulkan_global_binding_table.html#a3b3b04b4b0facebdcf317bacbecc1f49',1,'Ogre::VulkanGlobalBindingTable']]],
  ['readonlyistex_8',['ReadOnlyIsTex',['../struct_ogre_1_1_hlms_base_prop.html#ae7893b8cb9044e9748f3b6e71c134503',1,'Ogre::HlmsBaseProp']]],
  ['readywindowforpresent_9',['readyWindowForPresent',['../struct_ogre_1_1_frame_buffer_desc_key.html#a691a9bc217e8d778c781886d60528465',1,'Ogre::FrameBufferDescKey']]],
  ['receiveshadows_10',['ReceiveShadows',['../struct_ogre_1_1_pbs_property.html#af6f3ff51af3dd6e3a602a9d1fca3d92b',1,'Ogre::PbsProperty']]],
  ['recursive_11',['recursive',['../struct_ogre_1_1_resource_group_manager_1_1_resource_location.html#a89980295496fa459796c2561d0a40f3f',1,'Ogre::ResourceGroupManager::ResourceLocation']]],
  ['red_12',['Red',['../class_ogre_1_1_colour_value.html#ab9c2a36f53ac599850f1cf8b822f750d',1,'Ogre::ColourValue']]],
  ['reductionmethod_13',['reductionMethod',['../struct_ogre_1_1_lod_level.html#a45b8fffff2bc5dc6d29967a7678421e2',1,'Ogre::LodLevel']]],
  ['reductionvalue_14',['reductionValue',['../struct_ogre_1_1_lod_level.html#a10d85c3d0d1f9a03019a9abc76cf70d1',1,'Ogre::LodLevel']]],
  ['refcount_15',['refCount',['../struct_ogre_1_1_vulkan_frame_buffer_desc_value.html#a2eb5864588bbc5be21f30b065415aabe',1,'Ogre::VulkanFrameBufferDescValue::refCount()'],['../struct_ogre_1_1_vulkan_flush_only_desc_value.html#a6eb0794d7a7e0bd679d223945c5d3afb',1,'Ogre::VulkanFlushOnlyDescValue::refCount()'],['../struct_ogre_1_1_metal_frame_buffer_desc_value.html#a09a561ec6313a5f6914c72de168864d3',1,'Ogre::MetalFrameBufferDescValue::refCount()'],['../struct_ogre_1_1_d3_d11_frame_buffer_desc_value.html#a8476d92ad49a81a9c15d74ce9672ba4e',1,'Ogre::D3D11FrameBufferDescValue::refCount()'],['../struct_ogre_1_1_lod_data_1_1_edge.html#a7e0e58962a7fe713743728f63a5b39db',1,'Ogre::LodData::Edge::refCount()'],['../struct_ogre_1_1_g_l3_plus_frame_buffer_desc_value.html#aa358b1aeaa0708231846b09b18dcdfc3',1,'Ogre::GL3PlusFrameBufferDescValue::refCount()']]],
  ['reflectioncamera_16',['reflectionCamera',['../struct_ogre_1_1_active_actor_data.html#ab279747a88defe838d10146415f82857',1,'Ogre::ActiveActorData']]],
  ['reflectiontexture_17',['reflectionTexture',['../struct_ogre_1_1_active_actor_data.html#a51182669b555c0e59a061754ea9d2b39',1,'Ogre::ActiveActorData']]],
  ['reflnormal_18',['reflNormal',['../struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html#a9c195ea4eefb691fe469d805e88db24d',1,'Ogre::PlanarReflections::TrackedRenderable']]],
  ['refreshrate_19',['RefreshRate',['../struct_d_x_g_i___s_w_a_p___c_h_a_i_n___f_u_l_l_s_c_r_e_e_n___d_e_s_c.html#abc2879bd4b21de67a4e0d06929aad9e0',1,'DXGI_SWAP_CHAIN_FULLSCREEN_DESC']]],
  ['release_20',['release',['../struct_ogre_1_1_driver_version.html#ae682f3bab912af152cb3f6e8497815f6',1,'Ogre::DriverVersion']]],
  ['rendareblehlmstypemask_21',['RendarebleHlmsTypeMask',['../struct_ogre_1_1_hlms_bits.html#aa95210cbd33619cba7e5b8b22fb291f5',1,'Ogre::HlmsBits']]],
  ['renderable_22',['renderable',['../struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html#a9523732d7c8f78aad197574563f22ba6',1,'Ogre::PlanarReflections::TrackedRenderable::renderable()'],['../struct_ogre_1_1_queued_renderable.html#ad63644d36969a4f90efc8b88ec394518',1,'Ogre::QueuedRenderable::renderable()'],['../struct_ogre_1_1_cb_low_level_material.html#ac4e234229befb3dec94304c13e74e6a5',1,'Ogre::CbLowLevelMaterial::renderable()']]],
  ['renderablebits_23',['RenderableBits',['../struct_ogre_1_1_hlms_bits.html#a7c4a502448a66c6373a8763b49a12980',1,'Ogre::HlmsBits']]],
  ['renderablecache_24',['renderableCache',['../struct_ogre_1_1_hlms_disk_cache_1_1_pso.html#ab474d42949e1800fb64e0b3ab378de75',1,'Ogre::HlmsDiskCache::Pso']]],
  ['renderablecenter_25',['renderableCenter',['../struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html#a557d8b10d227e322a55e19c534d0dbf9',1,'Ogre::PlanarReflections::TrackedRenderable']]],
  ['renderablemask_26',['RenderableMask',['../struct_ogre_1_1_hlms_bits.html#a5b7ab7ed064fbf0e52998523a386168c',1,'Ogre::HlmsBits']]],
  ['renderableshift_27',['RenderableShift',['../struct_ogre_1_1_hlms_bits.html#a384f5dec64f797a0e381a52be85bf930',1,'Ogre::HlmsBits']]],
  ['renderdepthonly_28',['RenderDepthOnly',['../struct_ogre_1_1_hlms_base_prop.html#ae5365cca56bc9377b99e6e5e0fc7aefe',1,'Ogre::HlmsBaseProp']]],
  ['renderingcamera_29',['renderingCamera',['../struct_ogre_1_1_cameras_in_progress.html#a567376f824c9bbbb31f0f0981f0b605b',1,'Ogre::CamerasInProgress']]],
  ['renderop_30',['renderOp',['../struct_ogre_1_1_scene_query_1_1_world_fragment.html#a1489f689813fa881d0f025636d4b21a5',1,'Ogre::SceneQuery::WorldFragment']]],
  ['renderopmeshindex_31',['renderOpMeshIndex',['../class_ogre_1_1v1_1_1_sub_mesh.html#a2b8460357eae0bef7fb5b0ff1d6856cf',1,'Ogre::v1::SubMesh']]],
  ['renderpass_32',['renderPass',['../class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a813150978ba9eb43adc1f1f36ae28dfa',1,'Ogre::VulkanDelayed_vkDestroyRenderPass']]],
  ['renderqueue_33',['renderQueue',['../struct_ogre_1_1_scene_manager_1_1_render_context.html#a5c1ade5cb7839619d648dc116279d4fa',1,'Ogre::SceneManager::RenderContext']]],
  ['rendertovertexbuffer_34',['renderToVertexBuffer',['../class_ogre_1_1v1_1_1_render_operation.html#addcefa7b146fc277683d9802186854d3',1,'Ogre::v1::RenderOperation']]],
  ['repeat_35',['repeat',['../struct_ogre_1_1_vertex_element_semantic_full.html#a2be91d0fed7910a261f0806f6a240eae',1,'Ogre::VertexElementSemanticFull']]],
  ['requestedlod_36',['requestedLod',['../struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#aef02279bce06791298afaf3defc002b6',1,'Ogre::TerrainLodManager::LoadLodRequest']]],
  ['requestee_37',['requestee',['../struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#afa635e167e34d5bc7a75602205410928',1,'Ogre::TerrainLodManager::LoadLodRequest']]],
  ['reserved_5fvisibility_5fflags_38',['RESERVED_VISIBILITY_FLAGS',['../namespace_ogre_1_1_visibility_flags.html#a7726a5ff6639016d642e056532a62eee',1,'Ogre::VisibilityFlags']]],
  ['resolution_39',['resolution',['../struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a872db0ab4ff69396406a84eedf7f194a',1,'Ogre::TerrainLodManager::LodInfo::resolution()'],['../struct_ogre_1_1_shadow_node_helper_1_1_shadow_param.html#a3c998daa711709215e80cca254bc09b0',1,'Ogre::ShadowNodeHelper::ShadowParam::resolution()'],['../struct_ogre_1_1_vct_cascade_setting.html#a8f406fa8d63afdfb14826e962a8480d2',1,'Ogre::VctCascadeSetting::resolution()']]],
  ['resolvecolourformat_40',['resolveColourFormat',['../struct_ogre_1_1_hlms_pass_pso.html#a0eb4945bc9aa5f3a9b83bfcf1a758ae9',1,'Ogre::HlmsPassPso']]],
  ['resolvemiplevel_41',['resolveMipLevel',['../struct_ogre_1_1_render_target_view_entry.html#af49bb9dc39760c1624c994814b494560',1,'Ogre::RenderTargetViewEntry::resolveMipLevel()'],['../struct_ogre_1_1_render_pass_target_base.html#ae35b43bd7e138d99619208000d54f802',1,'Ogre::RenderPassTargetBase::resolveMipLevel()']]],
  ['resolveslice_42',['resolveSlice',['../struct_ogre_1_1_render_pass_target_base.html#af25253ac5a6aefe92b365c2468c58898',1,'Ogre::RenderPassTargetBase::resolveSlice()'],['../struct_ogre_1_1_render_target_view_entry.html#a22ece6c6b82c34306bef2a5e2875b590',1,'Ogre::RenderTargetViewEntry::resolveSlice()']]],
  ['resolvetexture_43',['resolveTexture',['../struct_ogre_1_1_render_pass_target_base.html#a7f41bdeafb1eb3a2e78ed102e0769626',1,'Ogre::RenderPassTargetBase']]],
  ['resolvetexturename_44',['resolveTextureName',['../struct_ogre_1_1_render_target_view_entry.html#ab11e004ece90bc212ce95a9af81dd5fb',1,'Ogre::RenderTargetViewEntry']]],
  ['resource_45',['resource',['../struct_ogre_1_1_resource_transition.html#a41266fce2a214bf806753d86587f5b6a',1,'Ogre::ResourceTransition']]],
  ['resource_5fsystem_5fnum_5freference_5fcounts_46',['RESOURCE_SYSTEM_NUM_REFERENCE_COUNTS',['../class_ogre_1_1_resource_group_manager.html#a2f859bb7ae7ea232379d238c8fdfd142',1,'Ogre::ResourceGroupManager']]],
  ['resourcegroup_47',['resourceGroup',['../struct_ogre_1_1_texture_gpu_manager_1_1_resource_entry.html#ae6479fe6bf6fcaaec2eabbcb166baab9',1,'Ogre::TextureGpuManager::ResourceEntry']]],
  ['resourcename_48',['resourceName',['../struct_ogre_1_1_hlms_texture_manager_1_1_texture_array_1_1_name_pair.html#a559f365959e8209a2502b997840e1dea',1,'Ogre::HlmsTextureManager::TextureArray::NamePair::resourceName()'],['../struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html#ae2e29633ab1798c3f99151618b963d73',1,'Ogre::ResourceGroupManager::ResourceDeclaration::resourceName()']]],
  ['resourcetype_49',['resourceType',['../struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html#aae401b65d364881e950953a3a15e2977',1,'Ogre::ResourceGroupManager::ResourceDeclaration']]],
  ['right_50',['right',['../struct_ogre_1_1_box.html#ac2c94e2d364dfabe7e4406ff8f41ab9e',1,'Ogre::Box::right()'],['../struct_ogre_1_1_t_rect.html#a56b6ad37d298b66bc7366431f6f786b5',1,'Ogre::TRect::right()']]],
  ['righteyecenter_51',['rightEyeCenter',['../struct_ogre_1_1_hidden_area_vr_settings.html#a1b5d29787fec37261fc1ad1a98b49324',1,'Ogre::HiddenAreaVrSettings']]],
  ['righteyeradius_52',['rightEyeRadius',['../struct_ogre_1_1_hidden_area_vr_settings.html#a8ab0b721d456556fcf54305f9c0c481c',1,'Ogre::HiddenAreaVrSettings']]],
  ['rightnosecenter_53',['rightNoseCenter',['../struct_ogre_1_1_hidden_area_vr_settings.html#a8729ee2ece54466fc992a6185c27b4f1',1,'Ogre::HiddenAreaVrSettings']]],
  ['rightnoseradius_54',['rightNoseRadius',['../struct_ogre_1_1_hidden_area_vr_settings.html#aac400000cac5c745ff5980999a3b9181',1,'Ogre::HiddenAreaVrSettings']]],
  ['rmask_55',['rmask',['../struct_ogre_1_1_pixel_format_description.html#ab87f0fc49ed7c0ec3f6c06ef091b4c0d',1,'Ogre::PixelFormatDescription']]],
  ['root_56',['root',['../struct_ogre_1_1_volume_1_1_chunk_request.html#a9350bd2d943fe62ca4ee0eb3f7b5c6ec',1,'Ogre::Volume::ChunkRequest::root()'],['../struct_x_window_attributes.html#aa21f585b094bf093a8b41db91ff23867',1,'XWindowAttributes::root()']]],
  ['rootlayout_57',['rootLayout',['../struct_ogre_1_1_vulkan_hlms_pso.html#a0c1a24aaa8711f608dc67f6390fa8eb7',1,'Ogre::VulkanHlmsPso']]],
  ['roughnessisshininess_58',['RoughnessIsShininess',['../struct_ogre_1_1_pbs_property.html#a3316a6e95bed9036eb42c29bdd11d11d',1,'Ogre::PbsProperty']]],
  ['roughnessmap_59',['RoughnessMap',['../struct_ogre_1_1_pbs_property.html#a8a2287f563678877042f98547728546d',1,'Ogre::PbsProperty::RoughnessMap()'],['../struct_ogre_1_1_pbs_mobile_property.html#ae8b81dc5cfebaec48bfb79373378a591',1,'Ogre::PbsMobileProperty::RoughnessMap()']]],
  ['rowpitch_60',['rowPitch',['../class_ogre_1_1_pixel_box.html#aacf8f1ebed40c557389d9d1e9dda3b68',1,'Ogre::PixelBox']]],
  ['rscontext_61',['rsContext',['../struct_ogre_1_1_scene_manager_1_1_render_context.html#a25d8314d6131f2b7ef384ecc06277a83',1,'Ogre::SceneManager::RenderContext']]],
  ['rsdata_62',['rsData',['../struct_ogre_1_1_hlms_pso.html#a9239c7de65f013a164846fb2ebc18fe1',1,'Ogre::HlmsPso::rsData()'],['../struct_ogre_1_1_hlms_compute_pso.html#af57863851806d10ff62f1bf154b5e7bd',1,'Ogre::HlmsComputePso::rsData()']]],
  ['rshift_63',['rshift',['../struct_ogre_1_1_pixel_format_description.html#a7e4ecbc641602206e178ebc5fc0f8c0f',1,'Ogre::PixelFormatDescription']]],
  ['rttorbuffer_64',['rttOrBuffer',['../struct_ogre_1_1_bound_uav.html#ad099daaef4fdd709643d7cb13ef98d79',1,'Ogre::BoundUav']]]
];
